<?php

namespace Restaurant\Schedule\Policies;

use Litepie\User\Contracts\UserPolicy;
use Restaurant\Schedule\Models\RestaurantSchedule;

class RestaurantSchedulePolicy
{

    /**
     * Determine if the given user can view the restaurant_schedule.
     *
     * @param UserPolicy $user
     * @param RestaurantSchedule $restaurant_schedule
     *
     * @return bool
     */
    public function view(UserPolicy $user, RestaurantSchedule $restaurant_schedule)
    {
        if ($user->canDo('schedule.restaurant_schedule.view') && $user->isAdmin()) {
            return true;
        }

        return $restaurant_schedule->user_id == user_id() && $restaurant_schedule->user_type == user_type();
    }

    /**
     * Determine if the given user can create a restaurant_schedule.
     *
     * @param UserPolicy $user
     * @param RestaurantSchedule $restaurant_schedule
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('schedule.restaurant_schedule.create');
    }

    /**
     * Determine if the given user can update the given restaurant_schedule.
     *
     * @param UserPolicy $user
     * @param RestaurantSchedule $restaurant_schedule
     *
     * @return bool
     */
    public function update(UserPolicy $user, RestaurantSchedule $restaurant_schedule)
    {
        if ($user->canDo('schedule.restaurant_schedule.edit') && $user->isAdmin()) {
            return true;
        }

        return $restaurant_schedule->user_id == user_id() && $restaurant_schedule->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given restaurant_schedule.
     *
     * @param UserPolicy $user
     * @param RestaurantSchedule $restaurant_schedule
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, RestaurantSchedule $restaurant_schedule)
    {
        return $restaurant_schedule->user_id == user_id() && $restaurant_schedule->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given restaurant_schedule.
     *
     * @param UserPolicy $user
     * @param RestaurantSchedule $restaurant_schedule
     *
     * @return bool
     */
    public function verify(UserPolicy $user, RestaurantSchedule $restaurant_schedule)
    {
        if ($user->canDo('schedule.restaurant_schedule.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given restaurant_schedule.
     *
     * @param UserPolicy $user
     * @param RestaurantSchedule $restaurant_schedule
     *
     * @return bool
     */
    public function approve(UserPolicy $user, RestaurantSchedule $restaurant_schedule)
    {
        if ($user->canDo('schedule.restaurant_schedule.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
