<?php

namespace Restaurant\Schedule\Providers;

use Illuminate\Support\ServiceProvider;

class ScheduleServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'schedule');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'schedule');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('restaurant.schedule', function ($app) {
            return $this->app->make('Restaurant\Schedule\Schedule');
        });

                // Bind RestaurantSchedule to repository
        $this->app->bind(
            'Restaurant\Schedule\Interfaces\RestaurantScheduleRepositoryInterface',
            \Restaurant\Schedule\Repositories\Eloquent\RestaurantScheduleRepository::class
        );

        $this->app->register(\Restaurant\Schedule\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Restaurant\Schedule\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['restaurant.schedule'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('restaurant/schedule.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/schedule')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/schedule')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
